# Generated by ariadne-codegen
# Source: openhexa/graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import UpdateOrganizationError


class UpdateOrganization(BaseModel):
    update_organization: "UpdateOrganizationUpdateOrganization" = Field(
        alias="updateOrganization"
    )


class UpdateOrganizationUpdateOrganization(BaseModel):
    success: bool
    errors: List[UpdateOrganizationError]
    organization: Optional["UpdateOrganizationUpdateOrganizationOrganization"]


class UpdateOrganizationUpdateOrganizationOrganization(BaseModel):
    id: Any
    name: str
    short_name: Optional[str] = Field(alias="shortName")
    logo: Optional[str]


UpdateOrganization.model_rebuild()
UpdateOrganizationUpdateOrganization.model_rebuild()
