# Generated by ariadne-codegen
# Source: openhexa/graphql/queries.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .enums import PipelineError


class UpdatePipelineHeartbeat(BaseModel):
    update_pipeline_heartbeat: "UpdatePipelineHeartbeatUpdatePipelineHeartbeat" = Field(
        alias="updatePipelineHeartbeat"
    )


class UpdatePipelineHeartbeatUpdatePipelineHeartbeat(BaseModel):
    success: bool
    errors: List[PipelineError]


UpdatePipelineHeartbeat.model_rebuild()
