# Generated by ariadne-codegen
# Source: openhexa/graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CreateOrganizationError


class CreateOrganization(BaseModel):
    create_organization: "CreateOrganizationCreateOrganization" = Field(
        alias="createOrganization"
    )


class CreateOrganizationCreateOrganization(BaseModel):
    success: bool
    errors: List[CreateOrganizationError]
    organization: Optional["CreateOrganizationCreateOrganizationOrganization"]
    user: Optional["CreateOrganizationCreateOrganizationUser"]


class CreateOrganizationCreateOrganizationOrganization(BaseModel):
    id: Any
    name: str
    short_name: Optional[str] = Field(alias="shortName")


class CreateOrganizationCreateOrganizationUser(BaseModel):
    id: Any
    email: str
    display_name: str = Field(alias="displayName")


CreateOrganization.model_rebuild()
CreateOrganizationCreateOrganization.model_rebuild()
