# Generated by ariadne-codegen
# Source: openhexa/graphql/queries.graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import BucketObjectType


class GetFileByPath(BaseModel):
    get_file_by_path: Optional["GetFileByPathGetFileByPath"] = Field(
        alias="getFileByPath"
    )


class GetFileByPathGetFileByPath(BaseModel):
    key: str
    name: str
    path: str
    size: Optional[Any]
    type: BucketObjectType


GetFileByPath.model_rebuild()
